{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% load gravatar %}
{% block titletag %}{% trans "Create a flag for all domains" as flags_str %}{% endblock %}

{% block content %}
    {% trans "Create a flag for all domains" as flags_str %}
    {% trans "Add a flag" as add_a_flag_str %}

    {% include "wagtailadmin/shared/header.html" with title=flags_str icon="tag" %}

    <h2 class="nice-padding">New flag name:</h2>
    <form class="nice-padding" method="POST" action="{% url 'flagadmin:create' %}">
        {% csrf_token %}
        <ul class="fields">
            <li class="actions">
                {% for field in form %}
                    {% if field.errors %}
                        <div class="help-block help-critical" style="margin-top:0;">
                            {{ field.errors }}
                        </div>
                    {% endif %}
                    <input placeholder="enter new flag name" name="{{ field.name }}" />
                {% endfor %}
            </li>
            <li class="actions">
                <input class="button action-save button-longrunning" type="submit" value="save new flag" />
                <a class="button bicolor icon icon-cog" href="{% url 'flagadmin:list' 1 %}">Back to flag settings…</a>
            </li>
        </ul>
    </form>
{% endblock %}
