{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% load gravatar %}
{% block titletag %}{% trans "Delete" as delete_str %}: {{ flag_id }}{% endblock %}

{% block content %}
    {% trans "Delete:" as delete_str %}
    {% include "wagtailadmin/shared/header.html" with title=delete_str subtitle=flag_id %}

    <form class="nice-padding" method="POST" action="{% url 'flagadmin:delete' flag_id %}">
      {% csrf_token %}

      <p>Are you sure you want to delete this flag?</p>
      <input type="submit" value="Yes, delete it" class="button serious">
      <a href="{% url 'flagadmin:select_site' %}" class="button button-secondary">No, don't delete it</a>
    </form>
{% endblock %}
